pub struct Bencher { /* private fields */ }Implementations
Sourceimpl Bencher
impl Bencher
pub fn new() -> Self
Sourcepub fn set_iterations(&mut self, iterations: usize) -> &mut Self
pub fn set_iterations(&mut self, iterations: usize) -> &mut Self
Sets the number of iterations a benchmark will be run If set to 0 it iterates until the standard deviation is below 1%
pub fn set_max_iterations(&mut self, iterations: usize) -> &mut Self
Sourcepub fn bench<T, F: FnMut() -> T>(&mut self, name: &str, func: F) -> &mut Self
pub fn bench<T, F: FnMut() -> T>(&mut self, name: &str, func: F) -> &mut Self
Benchmarks a closure a configured number of times. The result will be printed to the console with the given name.
Sourcepub fn compare(&mut self) -> &mut Self
pub fn compare(&mut self) -> &mut Self
Compares the last two benchmarks If the number of benchmarks is below 2 it doesn’t do anything
Sourcepub fn print_settings(&mut self) -> &mut Self
pub fn print_settings(&mut self) -> &mut Self
Prints the settings of the Bencher
Sourcepub fn write_output_to(&mut self, writer: BufWriter<File>) -> &mut Self
pub fn write_output_to(&mut self, writer: BufWriter<File>) -> &mut Self
Adds a file to write the output to
pub fn flush(&mut self) -> Result<()>